/*
 * avrgal.c - Main for avrgal
 *
 *
 * Copyright (C) 2010  David Anders <danders@rad-tech-labs.com>
 * Copyright (C) 2010  TinCanTools <sales@tincantools.com>
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 *
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <fcntl.h>
#include <unistd.h>
#include <getopt.h>
#include <termios.h>
#include <sys/ioctl.h>

#include "protocol.h"
#include "fileio.h"

void print_usage(char *prg)
{
	fprintf(stderr, "\nUsage: %s filename\n\n", prg);
	fprintf(stderr, "Options: -p <port>      (port to use)\n");
	fprintf(stderr, "         -?             (show this help)\n");
	fprintf(stderr, "\nExample:\n");
	fprintf(stderr, "avrgal main.hex -p /dev/ttyUSB3\n");
	fprintf(stderr, "\n");
	exit(1);
}

int main(int argc, char **argv)
{
	int fd,ret,n_bytes;
	char *tty;
	int tty_set=0;
	char *filename;
	int opt;
	unsigned char buf[32768];

	
	while ((opt = getopt(argc, argv, "p:?")) != -1) {
		switch (opt) {
		case 'p':
			tty = optarg;
			tty_set=1;
			break;
		case '?':
		default:
			print_usage(argv[0]);
			break;
		}
	}
    
    	if (argc - optind != 1)
		print_usage(argv[0]);

	filename = argv[optind];
	if(tty_set == 0 )
    	    tty = "/dev/ttyS1";
                                    
	printf("Uart port used                      : %s\n",tty);

	n_bytes=fileio(FIO_READ, filename , buf, FMT_AUTO, 0);
	
	fd=protocol_open(tty,57600);
	
	printf("Acquire SYNC with AVR               : ");
	ret=protocol_getsync(fd);
	if (ret==0) {
	    printf("Passed\n");
	}
	else {
	    printf("Failed\n");
	    exit(1);
	}

	printf("Uploading and writing to flash      : ");
	ret=protocol_paged_write(fd, buf,128, n_bytes);
	if (ret==n_bytes) {
	    printf("Passed\n");
	}
	else {
	    printf("Failed\n");
	    exit(1);
	}



	protocol_close(fd);
	
	return 0;
}
